summaryrefslogtreecommitdiff
path: root/nuttx/fs/procfs
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/fs/procfs')
-rw-r--r--nuttx/fs/procfs/fs_procfs.c4
-rw-r--r--nuttx/fs/procfs/fs_procfscpuload.c2
-rw-r--r--nuttx/fs/procfs/fs_procfsproc.c6
-rw-r--r--nuttx/fs/procfs/fs_procfsuptime.c2
-rw-r--r--nuttx/fs/procfs/fs_skeleton.c6
5 files changed, 10 insertions, 10 deletions
diff --git a/nuttx/fs/procfs/fs_procfs.c b/nuttx/fs/procfs/fs_procfs.c
index 3351d7bf8..d4471e554 100644
--- a/nuttx/fs/procfs/fs_procfs.c
+++ b/nuttx/fs/procfs/fs_procfs.c
@@ -435,7 +435,7 @@ static int procfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
*/
level0 = (FAR struct procfs_level0_s *)
- kzalloc(sizeof(struct procfs_level0_s));
+ kmm_zalloc(sizeof(struct procfs_level0_s));
if (!level0)
{
@@ -514,7 +514,7 @@ static int procfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
*/
level1 = (FAR struct procfs_level1_s *)
- kzalloc(sizeof(struct procfs_level1_s));
+ kmm_zalloc(sizeof(struct procfs_level1_s));
if (!level1)
{
diff --git a/nuttx/fs/procfs/fs_procfscpuload.c b/nuttx/fs/procfs/fs_procfscpuload.c
index 9d01bcad3..8641f3933 100644
--- a/nuttx/fs/procfs/fs_procfscpuload.c
+++ b/nuttx/fs/procfs/fs_procfscpuload.c
@@ -166,7 +166,7 @@ static int cpuload_open(FAR struct file *filep, FAR const char *relpath,
/* Allocate a container to hold the file attributes */
- attr = (FAR struct cpuload_file_s *)kzalloc(sizeof(struct cpuload_file_s));
+ attr = (FAR struct cpuload_file_s *)kmm_zalloc(sizeof(struct cpuload_file_s));
if (!attr)
{
fdbg("ERROR: Failed to allocate file attributes\n");
diff --git a/nuttx/fs/procfs/fs_procfsuptime.c b/nuttx/fs/procfs/fs_procfsuptime.c
index 2d1d02a25..0135e0717 100644
--- a/nuttx/fs/procfs/fs_procfsuptime.c
+++ b/nuttx/fs/procfs/fs_procfsuptime.c
@@ -168,7 +168,7 @@ static int uptime_open(FAR struct file *filep, FAR const char *relpath,
/* Allocate a container to hold the file attributes */
- attr = (FAR struct uptime_file_s *)kzalloc(sizeof(struct uptime_file_s));
+ attr = (FAR struct uptime_file_s *)kmm_zalloc(sizeof(struct uptime_file_s));
if (!attr)
{
fdbg("ERROR: Failed to allocate file attributes\n");
diff --git a/nuttx/fs/procfs/fs_skeleton.c b/nuttx/fs/procfs/fs_skeleton.c
index 28f5ff051..55a9d769e 100644
--- a/nuttx/fs/procfs/fs_skeleton.c
+++ b/nuttx/fs/procfs/fs_skeleton.c
@@ -179,7 +179,7 @@ static int skel_open(FAR struct file *filep, FAR const char *relpath,
/* Allocate a container to hold the task and attribute selection */
- priv = (FAR struct skel_file_s *)kzalloc(sizeof(struct skel_file_s));
+ priv = (FAR struct skel_file_s *)kmm_zalloc(sizeof(struct skel_file_s));
if (!priv)
{
fdbg("ERROR: Failed to allocate file attributes\n");
@@ -268,7 +268,7 @@ static int skel_dup(FAR const struct file *oldp, FAR struct file *newp)
/* Allocate a new container to hold the task and attribute selection */
- newpriv = (FAR struct skel_file_s *)kzalloc(sizeof(struct skel_file_s));
+ newpriv = (FAR struct skel_file_s *)kmm_zalloc(sizeof(struct skel_file_s));
if (!newpriv)
{
fdbg("ERROR: Failed to allocate file attributes\n");
@@ -305,7 +305,7 @@ static int skel_opendir(FAR const char *relpath, FAR struct fs_dirent_s *dir)
*/
level1 = (FAR struct skel_level1_s *)
- kzalloc(sizeof(struct skel_level1_s));
+ kmm_zalloc(sizeof(struct skel_level1_s));
if (!level1)
{
diff --git a/nuttx/fs/procfs/fs_procfsproc.c b/nuttx/fs/procfs/fs_procfsproc.c
index 15625c22a..cd3976286 100644
--- a/nuttx/fs/procfs/fs_procfsproc.c
+++ b/nuttx/fs/procfs/fs_procfsproc.c
@@ -978,7 +978,7 @@ static int proc_open(FAR struct file *filep, FAR const char *relpath,
/* Allocate a container to hold the task and node selection */
- procfile = (FAR struct proc_file_s *)kzalloc(sizeof(struct proc_file_s));
+ procfile = (FAR struct proc_file_s *)kmm_zalloc(sizeof(struct proc_file_s));
if (!procfile)
{
fdbg("ERROR: Failed to allocate file container\n");
@@ -1197,11 +1197,11 @@ static int proc_opendir(FAR const char *relpath, FAR struct fs_dirent_s *dir)
}
/* Allocate the directory structure. Note that the index and procentry
* pointer are implicitly nullified by kzalloc(). Only the remaining,
* non-zero entries will need be initialized.
*/
- procdir = (FAR struct proc_dir_s *)kzalloc(sizeof(struct proc_dir_s));
+ procdir = (FAR struct proc_dir_s *)kmm_zalloc(sizeof(struct proc_dir_s));
if (!procdir)
{
fdbg("ERROR: Failed to allocate the directory structure\n");
@@ -1197,11 +1197,11 @@ static int proc_opendir(FAR const char *relpath, FAR struct fs_dirent_s *dir)
}
/* Allocate the directory structure. Note that the index and procentry
- * pointer are implicitly nullified by kzalloc(). Only the remaining,
+ * pointer are implicitly nullified by kmm_zalloc(). Only the remaining,
* non-zero entries will need be initialized.
*/